//+------------------------------------------------------------------+
//|                                                  StupidTrade.mq5 |
//|                                                Maxim A.Kuznetsov |
//|                                          https://www.luxtrade.tk |
//+------------------------------------------------------------------+
#property copyright "Maxim A.Kuznetsov"
#property link      "https://www.luxtrade.tk"
#property version   "1.00"

//--- input parameters
#include "MT4Orders.mqh"

input int      STUPID_HOUR=7;
input int      STUPID_MIN=0;
input int      MIN_TP=30;
input int      MAX_TP=3000;
input int      TP_INCR=75;
input int      TP_DECR=100;
input double   LOTS=0.01;
input int      MAGIC=23431;

datetime dayTime=0;
datetime nextDay=0;
double stupidPrice=0;
datetime stupidTime=0;
int stupidTake=0;

int OnInit()
{
   EventSetTimer(10);
   OnDay();
   stupidPrice=0;
   if (stupidTime<TimeCurrent()) {
      stupidTime+=24*60*60;
   }
   return(INIT_SUCCEEDED);
}

void OnDeinit(const int reason)
{
   EventKillTimer();
}

void OnTick()
{
   datetime now=TimeCurrent();
   if (now>=nextDay) OnDay();
   if (stupidTime!=0 && now>stupidTime) {
      double bid=iClose(_Symbol,PERIOD_M1,0);
      if (stupidPrice!=0) {
         if (stupidTake==0) {
            stupidTake=(int)(3*MathAbs(bid-stupidPrice)/_Point);
         }
         if (bid>stupidPrice+_Point) Buy();
         else if (bid<stupidPrice-_Point) Sell();
      }
      stupidPrice=bid;
      stupidTime=0;
   }
}

void OnTimer()
{
   datetime now=TimeCurrent();
   if (now>=nextDay) OnDay();
}
void Buy()
{
   CloseAll(-1);
   OpenOrder(OP_BUY,LOTS);
   //OpenOrder(OP_SELL,LOTS);
}
void Sell()
{
   CloseAll(-1);
   OpenOrder(OP_SELL,LOTS);
   //OpenOrder(OP_BUY,LOTS);
}
void CloseAll(int op)
{
   bool hasClose=false;
   for(int pos=OrdersTotal()-1;pos>=0;pos--) {
      if (!OrderSelect(pos,SELECT_BY_POS,MODE_TRADES)) {
         continue;
      }
      if (OrderMagicNumber()!=MAGIC) continue;
      if (OrderSymbol()!=_Symbol) continue;
      if (op!=-1 && OrderType()!=op) continue;
      if (!OrderClose(OrderTicket(),OrderLots(),OrderClosePrice(),0)) {
         PrintFormat("Unable to close order %lld",OrderTicket());
      } else {
         hasClose=true;
      }
   }
   if (hasClose) {
      stupidTake=stupidTake-TP_DECR;
      if (stupidTake<MIN_TP) stupidTake=MIN_TP;
   } else {
      stupidTake=stupidTake+TP_INCR;
      if (stupidTake>MAX_TP) stupidTake=MAX_TP;
   }
}
bool OpenOrder(int op,double lots) 
{
   double price=SymbolInfoDouble(_Symbol,SYMBOL_BID);
   if (op==OP_BUY) price=SymbolInfoDouble(_Symbol,SYMBOL_ASK);
   long ticket=-1;
   if ((ticket=OrderSend(_Symbol,op,lots,price,0,0,0,"",MAGIC))>0 && OrderSelect(ticket,SELECT_BY_TICKET)) {
      double tp=NormalizeDouble(OrderOpenPrice()+stupidTake*_Point,_Digits);
      if (op==OP_SELL) {
         tp=NormalizeDouble(OrderOpenPrice()-stupidTake*_Point,_Digits);
      }
      if (!OrderModify(ticket,OrderOpenPrice(),0,tp,0)) {
         Print("OrderModify() failed");
      }
   }
   return ticket>0;
}
void OnDay()
{
   datetime now=TimeCurrent();
   MqlDateTime dt; TimeToStruct(now,dt);
   dt.hour=dt.min=dt.sec=0;
   dayTime=StructToTime(dt);
   nextDay=dayTime+24*60*60;
   stupidTime=dayTime+STUPID_HOUR*60*60+STUPID_MIN*60;
}
